import React from "react";
import moment from 'moment'; // 设置纯展示模式下的级联选择显示值

var setCascaderValue = function setCascaderValue(value, props) {
  var selectOptions = props.selectOptions,
      defaultProps = props.defaultProps;
  if (!value || value.length === 0 || !selectOptions) return '-'; // 无值情况 下

  var matchNode = undefined;
  var matchValueItems = [];
  value.forEach(function (valKey) {
    var matchValue; // 第一个值使用  ‘selectOptions’查找，后面使用上一次匹配到的父节点查找 matchNode

    if (matchNode && matchNode.children) {
      matchValue = matchNode.children.filter(function (seItem) {
        return seItem.value === valKey;
      });
    } else {
      matchValue = selectOptions.filter(function (seItem) {
        return seItem.value === valKey;
      });
    }

    if (matchValue.length > 0) {
      matchNode = matchValue[0];
      matchValueItems.push(matchValue[0]);
    }
  }); // 如果自定义"选择后展示的渲染函数"则直接返回此选择方法

  if (defaultProps.displayRender) return defaultProps.displayRender(matchValueItems.map(function (item) {
    return item.label;
  }), matchValueItems);
  return matchValueItems.map(function (item) {
    return item.label;
  }).join('/');
}; // 设置纯展示模式下的下拉、单选、多选表单值


var setSelectValue = function setSelectValue(value, props) {
  var selectOptions = props.selectOptions,
      selectOptionRender = props.selectOptionRender,
      defaultProps = props.defaultProps,
      type = props.type,
      separator = props.separator;
  var labelInValue = defaultProps.labelInValue;
  if (!value && value !== 0 || !selectOptions) return '-'; // 无值情况 下
  // 数组情况

  if (Array.isArray(value)) {
    if (value.length === 0) {
      return '-'; // 无值情况 下
    } // 返回是数组


    var matchValues = [];
    value.forEach(function (valKey, index) {
      var matchValue = selectOptions.filter(function (seItem) {
        return seItem.value === (labelInValue ? valKey.value : valKey);
      });

      if (matchValue.length > 0) {
        // 如果 select 配置选项展示内容，则直接使用其配置值展示当前只读信息
        if (selectOptionRender) {
          matchValues.push( /*#__PURE__*/React.createElement("div", {
            key: index,
            className: "checkbox-viewonly-item"
          }, selectOptionRender(matchValue[0]), value.length - 1 > index ? separator ? separator : separator === null ? '' : ',' : ''));
        } else {
          matchValues.push(matchValue[0].label);
        }
      }
    }); // 如果 select 配置选项展示内容，则直接使用其配置值展示当前只读信息

    if (selectOptionRender) {
      return /*#__PURE__*/React.createElement("div", {
        className: "checkbox-viewonly-list"
      }, matchValues);
    }

    return matchValues.join(separator ? separator : ',');
  } else {
    // 如select配置labelInValue则value返回数据是对象{key: 'xxx'}
    var matchValue = selectOptions.filter(function (seItem) {
      return seItem.value === (labelInValue ? value.value : value);
    }); // 如果 select 配置选项展示内容，则直接使用其配置值展示当前只读信息

    if (selectOptionRender) {
      return matchValue.length > 0 ? selectOptionRender(matchValue[0]) : '-';
    }

    return matchValue.length > 0 ? matchValue[0].label : '-';
  }
}; // 设置纯展示模式下的日期控件值


var setDatePickerValue = function setDatePickerValue(value, props) {
  var type = props.type,
      protoConfig = props.protoConfig;
  if (!value && value !== 0) return '-'; // 无值情况 下
  // 数组情况 'YYYY-MM-DD HH:mm:ss' : 'YYYY-MM-DD'

  switch (type) {
    case 'datePicker':
      return moment(value).format(protoConfig && protoConfig.format || 'YYYY-MM-DD');
      break;

    case 'dateTimePicker':
      return moment(value).format(protoConfig && protoConfig.format || 'YYYY-MM-DD HH:mm:ss');
      break;

    case 'rangePicker':
      return "".concat(moment(value[0]).format(protoConfig && protoConfig.format || 'YYYY-MM-DD'), " - ").concat(moment(value[1]).format(protoConfig && protoConfig.format || 'YYYY-MM-DD'));
      break;

    case 'rangeTimePicker':
      return "".concat(moment(value[0]).format(protoConfig && protoConfig.format || 'YYYY-MM-DD  HH:mm:ss'), " - ").concat(moment(value[1]).format(protoConfig && protoConfig.format || 'YYYY-MM-DD  HH:mm:ss'));
      break;

    case 'monthPicker':
      return moment(value).format(protoConfig && protoConfig.format || 'MM月');
      break;

    default:
      return '-';
      break;
  }
}; // 设置纯展示模式下的时间控件值


var setTimePickerValue = function setTimePickerValue(value, props) {
  var type = props.type,
      protoConfig = props.protoConfig;
  if (!value && value !== 0) return '-'; // 无值情况 下

  switch (type) {
    case 'timePicker':
      return moment(value).format(protoConfig && protoConfig.format || 'HH:mm:ss');
      break;

    case 'timePickerRange':
      return "".concat(moment(value[0]).format(protoConfig && protoConfig.format || 'HH:mm:ss'), " - ").concat(moment(value[1]).format(protoConfig && protoConfig.format || 'HH:mm:ss'));
      break;

    default:
      return '-';
      break;
  }
}; // 设置纯展示模式下上传控件显示值


var setUploaderValue = function setUploaderValue(value, props) {
  if (!value && value !== 0) return '-'; // 无值情况 下

  return /*#__PURE__*/React.createElement("div", {
    className: "spec-uploader-viewonly"
  }, Array.isArray(value) ? value.map(function (item, index) {
    return /*#__PURE__*/React.createElement("div", {
      key: index,
      className: "spec-uploader-viewonly-item"
    }, item.downloadUrl ? /*#__PURE__*/React.createElement("img", {
      className: "ant-upload-list-item-image",
      src: item.downloadUrl,
      alt: ""
    }) : '暂无图片');
  }) : /*#__PURE__*/React.createElement("div", {
    className: "spec-uploader-viewonly-item"
  }, value ? /*#__PURE__*/React.createElement("img", {
    className: "ant-upload-list-item-image",
    src: value,
    alt: ""
  }) : '暂无图片'));
};

export { setCascaderValue, setSelectValue, setDatePickerValue, setTimePickerValue, setUploaderValue };