"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _api = require("./api");

function asyncGeneratorStep(gen, resolve, reject, _next, _throw, key, arg) { try { var info = gen[key](arg); var value = info.value; } catch (error) { reject(error); return; } if (info.done) { resolve(value); } else { Promise.resolve(value).then(_next, _throw); } }

function _asyncToGenerator(fn) { return function () { var self = this, args = arguments; return new Promise(function (resolve, reject) { var gen = fn.apply(self, args); function _next(value) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "next", value); } function _throw(err) { asyncGeneratorStep(gen, resolve, reject, _next, _throw, "throw", err); } _next(undefined); }); }; }

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && Symbol.iterator in Object(iter)) return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function _classCallCheck(instance, Constructor) { if (!(instance instanceof Constructor)) { throw new TypeError("Cannot call a class as a function"); } }

function _defineProperties(target, props) { for (var i = 0; i < props.length; i++) { var descriptor = props[i]; descriptor.enumerable = descriptor.enumerable || false; descriptor.configurable = true; if ("value" in descriptor) descriptor.writable = true; Object.defineProperty(target, descriptor.key, descriptor); } }

function _createClass(Constructor, protoProps, staticProps) { if (protoProps) _defineProperties(Constructor.prototype, protoProps); if (staticProps) _defineProperties(Constructor, staticProps); return Constructor; }

var UploadQueue = /*#__PURE__*/function () {
  // 上传任务队列存储
  // 是否正在上传
  // 记录每个文件还剩下多少上传任务，作为判断文件是否完成上传的依据
  // 文件完成上传的回调函数
  function UploadQueue(_ref) {
    var fileFinishCb = _ref.fileFinishCb;

    _classCallCheck(this, UploadQueue);

    this.uploadQueue = [];
    this.isUploading = false;
    this.tasksSizePerFile = {};

    this.fileFinishCb = function () {};

    if (!!fileFinishCb && typeof fileFinishCb === 'function') {
      this.fileFinishCb = fileFinishCb;
    }
  }
  /**
   * 建立上传队列，规则：
   * 找出服务端记录里当前该文件所有状态为'wait'的文件分片
   * @param {Object} fileInfo 文件上传情况
   * @param {Array} chunksArr 分片数组
   */


  _createClass(UploadQueue, [{
    key: "addChunksToQueue",
    value: function addChunksToQueue(fileInfo, chunksArr) {
      console.log('addChunksToQueue=>建立上传队列=>', fileInfo, chunksArr);
      var newTasks = fileInfo.chunks.filter(function (chunk) {
        return chunk.status === 'wait';
      }).map(function (_, index) {
        return {
          hash: fileInfo.hash,
          index: index,
          chunk: chunksArr[index]
        };
      });
      /* 添加上传任务到队列中 */

      if (newTasks.length > 0) {
        this.uploadQueue = [].concat(_toConsumableArray(this.uploadQueue), _toConsumableArray(newTasks));
        this.tasksSizePerFile[newTasks[0].hash] = newTasks.length; // 记录当前文件有多少个上传任务
      }
    }
    /**
     * 触发上传
     */

  }, {
    key: "run",
    value: function run() {
      if (!this.isUploading) {
        this.isUploading = true;
        this.uploadNext(); // 开始上传
      }
    }
    /**
     * 上传下一个分片
     */

  }, {
    key: "uploadNext",
    value: function () {
      var _uploadNext = _asyncToGenerator( /*#__PURE__*/regeneratorRuntime.mark(function _callee() {
        var _this$uploadQueue$shi, chunkIndex, chunk, fileHash, lockResult;

        return regeneratorRuntime.wrap(function _callee$(_context) {
          while (1) {
            switch (_context.prev = _context.next) {
              case 0:
                if (!(this.uploadQueue.length === 0)) {
                  _context.next = 3;
                  break;
                }

                this.isUploading = false;
                return _context.abrupt("return");

              case 3:
                _this$uploadQueue$shi = this.uploadQueue.shift(), chunkIndex = _this$uploadQueue$shi.index, chunk = _this$uploadQueue$shi.chunk, fileHash = _this$uploadQueue$shi.hash; // 从上传队列里取出一个上传任务

                console.log('请求接口lockChunk=>给分片加锁，避免多个客户端上传同一个分片');
                /* 给分片加锁，避免多个客户端上传同一个分片 */

                _context.next = 7;
                return (0, _api.lockChunk)(fileHash, chunkIndex);

              case 7:
                lockResult = _context.sent;

                if (!lockResult) {
                  _context.next = 16;
                  break;
                }

                _context.next = 11;
                return (0, _api.uploadChunk)(fileHash, chunkIndex, chunk);

              case 11:
                console.log('请求接口uploadChunk=>上传分片文件,执行任务数递减', this.tasksSizePerFile);
                /* 判断该文件的所有分片是否都上传完（任务数递减为0时） */

                if (--this.tasksSizePerFile[fileHash] === 0) {
                  this.fileFinishCb(fileHash);
                  console.log('fileFinishCb=>该文件的所有分片已都上传完');
                }

                this.uploadNext();
                _context.next = 17;
                break;

              case 16:
                // 加锁失败，表示已有另一个客户端上传此分片，因此丢弃当前上传任务
                this.uploadNext();

              case 17:
              case "end":
                return _context.stop();
            }
          }
        }, _callee, this);
      }));

      function uploadNext() {
        return _uploadNext.apply(this, arguments);
      }

      return uploadNext;
    }()
  }]);

  return UploadQueue;
}();

exports.default = UploadQueue;