"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.transDataParam = transDataParam;
exports.resetDataWithLimit = resetDataWithLimit;

function _toConsumableArray(arr) { return _arrayWithoutHoles(arr) || _iterableToArray(arr) || _unsupportedIterableToArray(arr) || _nonIterableSpread(); }

function _nonIterableSpread() { throw new TypeError("Invalid attempt to spread non-iterable instance.\nIn order to be iterable, non-array objects must have a [Symbol.iterator]() method."); }

function _unsupportedIterableToArray(o, minLen) { if (!o) return; if (typeof o === "string") return _arrayLikeToArray(o, minLen); var n = Object.prototype.toString.call(o).slice(8, -1); if (n === "Object" && o.constructor) n = o.constructor.name; if (n === "Map" || n === "Set") return Array.from(o); if (n === "Arguments" || /^(?:Ui|I)nt(?:8|16|32)(?:Clamped)?Array$/.test(n)) return _arrayLikeToArray(o, minLen); }

function _iterableToArray(iter) { if (typeof Symbol !== "undefined" && Symbol.iterator in Object(iter)) return Array.from(iter); }

function _arrayWithoutHoles(arr) { if (Array.isArray(arr)) return _arrayLikeToArray(arr); }

function _arrayLikeToArray(arr, len) { if (len == null || len > arr.length) len = arr.length; for (var i = 0, arr2 = new Array(len); i < len; i++) { arr2[i] = arr[i]; } return arr2; }

function ownKeys(object, enumerableOnly) { var keys = Object.keys(object); if (Object.getOwnPropertySymbols) { var symbols = Object.getOwnPropertySymbols(object); if (enumerableOnly) symbols = symbols.filter(function (sym) { return Object.getOwnPropertyDescriptor(object, sym).enumerable; }); keys.push.apply(keys, symbols); } return keys; }

function _objectSpread(target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i] != null ? arguments[i] : {}; if (i % 2) { ownKeys(Object(source), true).forEach(function (key) { _defineProperty(target, key, source[key]); }); } else if (Object.getOwnPropertyDescriptors) { Object.defineProperties(target, Object.getOwnPropertyDescriptors(source)); } else { ownKeys(Object(source)).forEach(function (key) { Object.defineProperty(target, key, Object.getOwnPropertyDescriptor(source, key)); }); } } return target; }

function _defineProperty(obj, key, value) { if (key in obj) { Object.defineProperty(obj, key, { value: value, enumerable: true, configurable: true, writable: true }); } else { obj[key] = value; } return obj; }

/**
 * transDataParam 根据指定选项字段名重组数据
 *
 * @params {array} array 树数据集合
 * @params {object} optionName 选项字段值
 *
 * */
function transDataParam(array) {
  var optionName = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {
    key: 'key',
    value: 'key',
    title: 'title',
    children: 'children',
    disabled: 'disabled',
    selectable: 'selectable'
  };

  var trans = function trans(list) {
    if (!list) return null;
    return list.map(function (item) {
      if (item.hasOwnProperty(optionName.disabled || 'disabled')) {
        item.disabled = item[optionName.disabled || 'disabled'];
      }

      if (item.hasOwnProperty(optionName.selectable || 'selectable')) {
        item.disabled = item[optionName.selectable || 'selectable'];
      }

      if (item.hasOwnProperty(optionName.children || 'children')) {
        item.children = item[optionName.children || 'children'] ? trans(item[optionName.children || 'children']) : [];
      }

      return _objectSpread(_objectSpread({}, item), {}, {
        key: item[optionName.value || optionName.key || 'key'],
        title: item[optionName.title || 'title']
      });
    });
  };

  return trans(array);
}
/**
 * 根据限制字段limitKey进行重组数据
 *
 * @params {array} hasKeys 已选择的数据
 * @params {array} list 树数据集合
 * @params {array} resultList 返回结果数据
 * @params {object} optionName 选项字段值
 * @params {string} limitKey 指定限制字段名
 *
 * */


function resetDataWithLimit(hasKeys, list) {
  var optionName = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {
    key: 'key',
    value: 'key',
    title: 'title',
    children: 'children',
    disabled: 'disabled',
    selectable: 'selectable'
  };
  var limitKey = arguments.length > 3 ? arguments[3] : undefined;

  // 利用ID匹配对应选中的完整节点数据
  var filterCheckedNode = function filterCheckedNode(ids, preList) {
    var matchList = [];

    if (Array.isArray(preList) && preList.length > 0) {
      preList.forEach(function (item, i) {
        if (ids.includes(item[optionName.value || 'value'])) {
          matchList.push(_objectSpread({}, item));
        }

        if (item[optionName.children || 'children']) {
          matchList = matchList.concat(filterCheckedNode(ids, item[optionName.children || 'children']));
        }
      });
    }

    return matchList;
  }; // 筛选同一层级可选择，其他层级数据不可选择（限制按指定字段名的层级数据）


  var filterResetSameLevel = function filterResetSameLevel(preList, matchDataValue) {
    if (!matchDataValue) return preList;
    return preList.map(function (item) {
      item.disabled = item[limitKey] !== matchDataValue || item[optionName.disabled || 'disabled'];
      item.isLimit = item[limitKey] !== matchDataValue;
      item.children = filterResetSameLevel(item['children'], matchDataValue);
      item[optionName.children || 'children'] = filterResetSameLevel(item[optionName.children || 'children'], matchDataValue);
      return _objectSpread({}, item);
    });
  }; // 先筛选出来选中节点的数据，取其中的 level 层级的值(数据必须保证同级类型值一致)


  var filterLimitData = filterCheckedNode(hasKeys, list);

  var prevList = _toConsumableArray(list);

  if (filterLimitData.length > 0) {
    return filterResetSameLevel(prevList, filterLimitData[0][limitKey]);
  } else {
    return prevList;
  }
}