"use strict";

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.getNodePaths = exports.getChildrenNodes = exports.getParentNodes = void 0;

/**
 * @description  递归查看父级节点数据集合及当前节点数据
 * @params {Array}  list 当前需要过滤查看的数据集合、
 * @params {String/Array} nodeKey 当前用于查找匹配数据的标识值
 * @params {Object} params 指定当前数据中，筛选对应子集合字段名及匹配标识值字段名
 *                         （childrenParam：指当前子集合数据字段名（字符串表示单个，数组表示当前多个子集合字段名），keyParam： 指当前匹配标识值字段名）
 * @params {Object} extra
 *
 * @result {Array} nodeParent  当前传入nodeKey值所有上级别父级数据对象数组集合（倒序排列，根节点在最后一条）
 * @result {Array} parentKeys  当前传入nodeKey值所有上级别父级数据关键字数据集合(keyParam)（倒序排列，根节点在最后一条）
 * @result {Array} matchNode   当前传入nodeKey值所在的数据对象集合
 * */
var getParentNodes = function getParentNodes(list, nodeKey) {
  var params = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {
    childrenParam: 'children',
    keyParam: 'value'
  };
  var extraProps = arguments.length > 3 ? arguments[3] : undefined;
  // firstExtra 对应 rule值 SHOW_PARENT,SHOW_CHILD,SHOW_ALL 这几个值是由 'tree-select'控件配置返回的
  // const childrenParams = ['menuItems', 'menuFuncItems', 'items']
  var matchNode = [];
  var parentKeys = []; // 存储查找到的节点的父节点数据

  var nodeParent = []; // 存储查找到的节点的父节点数据
  // 移除上一次累加的数据

  var removePrevIndex = function removePrevIndex(array, item) {
    for (var i = 0; i < array.length; i += 1) {
      if (array[i][params.keyParam] === item[params.keyParam]) {
        return i;
      }
    }

    return null;
  };

  var deepFind = function deepFind(array, nodeId) {
    for (var i = 0; i < array.length; i += 1) {
      var node = array[i];

      if (node[params.keyParam] === nodeId) {
        matchNode.splice(0, 1, node); // 查找到则赋值，且跳出循环

        break;
      } // 如果是单个


      if (node[params.childrenParam] && node[params.childrenParam].length > 0) {
        deepFind(node[params.childrenParam] || node[params.childrenParam], nodeId);
        nodeParent.push(node); // 将当前节点数据存储到父节点数据中

        if (matchNode.length > 0) {
          break; // 在子节点查找到了，需要跳出
        } else {
          nodeParent.splice(removePrevIndex(nodeParent, node), 1); // 如果在子节点没有查找到，则将原来添加的父节点数据移除
        }
      } // 其他条件

      /* else if (node.menuFuncItems && node.menuFuncItems.length > 0) {
        deepFind(node.menuFuncItems, nodeId);
        nodeParent.push(node); // 将当前节点数据存储到父节点数据中
        if (matchNode.length > 0) {
          break; // 在子节点查找到了，需要跳出
        } else {
          nodeParent.splice(removePrevIndex(nodeParent, node), 1); // 如果在子节点没有查找到，则将原来添加的父节点数据移除
        }
      } else if (node.items && node.items.length > 0) {
        // 数据权限的子菜单集合 items
        deepFind(node.items, nodeId);
        nodeParent.push(node); // 将当前节点数据存储到父节点数据中
        if (matchNode.length > 0) {
          break; // 在子节点查找到了，需要跳出
        } else {
          nodeParent.splice(removePrevIndex(nodeParent, node), 1); // 如果在子节点没有查找到，则将原来添加的父节点数据移除
        }
      } else if (node.dataScopeList && node.dataScopeList.length > 0) {
        // 数据权限的子菜单集合 dataScopeList
        deepFind(node.dataScopeList, nodeId);
        nodeParent.push(node); // 将当前节点数据存储到父节点数据中
        if (matchNode.length > 0) {
          break; // 在子节点查找到了，需要跳出
        } else {
          nodeParent.splice(removePrevIndex(nodeParent, node), 1); // 如果在子节点没有查找到，则将原来添加的父节点数据移除
        }
      }*/

    }

    return matchNode; // 返回查找到的节点数据（格式为数组）
  }; // 查找单个节点


  var findMatchItem = function findMatchItem(arrList, key) {
    var matchItem;

    for (var i = 0; i < arrList.length; i += 1) {
      var node = arrList[i];

      if (node[params.keyParam] === key) {
        matchItem = node;
        break;
      }

      if (node[params.childrenParam]) {
        matchItem = findMatchItem(node[params.childrenParam], key);
      }
    }

    return matchItem;
  }; // nodeKey 为数组时返回当前数据（TODO。目前仅返回一级，多级情况未判断，且 nodeParent 值也未调整）


  if (Array.isArray(nodeKey)) {
    // const {showCheckedStrategy} = extraProps;
    // TODO 需要判断 showCheckedStrategy 值为 SHOW_PARENT、 SHOW_CHILD 、SHOW_ALL不同情况展示
    nodeKey.map(function (key) {
      var matchItem = findMatchItem(list, key);
      if (matchItem) matchNode.push(findMatchItem(list, key));
    });
  } else {
    deepFind(list, nodeKey);
  }

  nodeParent.forEach(function (par) {
    return parentKeys.push(par[params.keyParam]);
  }); // 将所有父节点的关键值（keyParam指定字段名）的数据集合在数组内

  return {
    nodeParent: nodeParent,
    parentKeys: parentKeys,
    matchNode: matchNode
  }; // 最终查找到的父节点数组 // nodeParent.concat(result || []);
}; // 递归查找指定ID所有的子菜单与子功能集合


exports.getParentNodes = getParentNodes;

var getChildrenNodes = function getChildrenNodes(childNode) {
  var params = arguments.length > 1 && arguments[1] !== undefined ? arguments[1] : {
    childrenParam: 'children',
    keyParam: 'value'
  };
  var childKeys = [];
  var nodeChildren = []; // 存储：authId, types

  var deepFindChild = function deepFindChild(cList) {
    Array.isArray(cList) && cList.forEach(function (item) {
      childKeys.push(item[params.keyParam]);
      nodeChildren.push(item);
      if (item[params.childrenParam]) deepFindChild(item[params.childrenParam]);
    });
  };

  deepFindChild(childNode);
  return {
    childKeys: childKeys,
    nodeChildren: nodeChildren
  };
}; // 查找节点路径


exports.getChildrenNodes = getChildrenNodes;

var getNodePaths = function getNodePaths(list, nodeKey) {
  var params = arguments.length > 2 && arguments[2] !== undefined ? arguments[2] : {
    childrenParam: 'children',
    keyParam: 'value'
  };
  var extraProps = arguments.length > 3 ? arguments[3] : undefined;

  // 获取指定节点的路径数组
  var getPathByKey = function getPathByKey(value, arr) {
    var findNodePath = function findNodePath(node, value, nodePathArray) {
      // 这里可以自定义push的内容，而不是整个node,而且这里node也包含了children
      nodePathArray.push(node); // 找到符合条件的节点，通过throw终止掉递归

      if (node[params.keyParam] === value) {
        // 也可以直接使用return;结束循环
        throw "over!";
      }

      if (node[params.childrenParam] && node[params.childrenParam].length > 0) {
        for (var i = 0; i < node[params.childrenParam].length; i++) {
          findNodePath(node[params.childrenParam][i], value, nodePathArray);
        } // 当前节点的子节点遍历完依旧没找到，则删除路径中的该节点


        nodePathArray.pop();
      } else {
        // 找到叶子节点时，删除路径当中的该叶子节点
        nodePathArray.pop();
      }
    }; // 用于存储节点唯一标识值路径数组


    var nodePathArray = [];

    try {
      for (var i = 0; i < arr.length; i++) {
        findNodePath(arr[i], value, nodePathArray);
      }
    } catch (e) {
      return nodePathArray;
    }
  };

  var pathNode = [];

  if (Array.isArray(nodeKey)) {
    nodeKey.map(function (key) {
      var pathItems = getPathByKey(key, list);
      if (pathItems) pathNode.push(pathItems);
    });
  }

  return pathNode;
};

exports.getNodePaths = getNodePaths;